@@ -13,14 +13,17 @@ def touches(df_boxscore):
 
     # helper function
     def compute_touches(row):
-      current_game_id = row['game_id']
-      current_team = row['team_id']
+        current_game_id = row['game_id']
+        current_team = row['team_id']
 
-      home_team_metric = df_groupby[(df_groupby['game_id'] == current_game_id) & (df_groupby['team_id'] == current_team)]
-      away_team_metric = df_groupby[(df_groupby['game_id'] == current_game_id) & (df_groupby['team_id'] != current_team)]
-
-      return row['fga'] + row['tov'] \
-        + (row['fta'] / (home_team_metric['fga'].to_list()[0] / away_team_metric['pf'].to_list()[0]) + row['ast']/0.17)
+        home_team_metric = df_groupby[(df_groupby['game_id'] == current_game_id) & (df_groupby['team_id'] == current_team)]
+        away_team_metric = df_groupby[(df_groupby['game_id'] == current_game_id) & (df_groupby['team_id'] != current_team)]
+        
+        try:
+            return row['fga'] + row['tov'] \
+                + (row['fta'] / (home_team_metric['fga'].to_list()[0] / away_team_metric['pf'].to_list()[0]) + row['ast']/0.17)
+        except:
+            return 0.0
 
     # Touches Formula=Field Goal Attempts + Turnovers + (Free Throw Attempts / (Team’s Free Throw Attempts/Opponents Personal Fouls)) + (Assists/0.17)
     df_groupby = df_boxscore.groupby(['game_id', 'team_id']).sum().reset_index()
